@@ -21,7 +21,7 @@ Usage::
     list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
     ```
 """
-from mypy_boto3_cloud9.client import Cloud9Client as Client, Cloud9Client
+from mypy_boto3_cloud9.client import Cloud9Client, Cloud9Client as Client
 from mypy_boto3_cloud9.paginator import (
     DescribeEnvironmentMembershipsPaginator,
     ListEnvironmentsPaginator,
